import random
def genrandint(minimal, maximal):
    return random.randint(minimal, maximal)
def shuffle(value):
    random.shuffle(value)
    return value
def ttn(text):
    return random.randint(0, len(text))



import subprocess

def run(apppath):
    try:
        # Use subprocess.run() to run the specified application
        subprocess.run(apppath, shell=True, check=True)
    except subprocess.CalledProcessError as e:
        print(f"Error: {e}")
    except FileNotFoundError as e:
        print(f"File not found: {e}")



from setuptools import setup, find_packages
import codecs
import os

VERSION = '6.0'
DESCRIPTION = 'helpfull tools'
long_description = 'helpfull tools'
setup(
    name='GuziX',
    version=VERSION,
    author='Chanakya Ram Sai Illa',
    author_email='Chanakyaramsaiilla@gmail.com',
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['numpy'],
    keywords=['grids', 'gtools'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


class Grid:
    def __init__(self, rows, columns):
        self.rows = rows
        self.columns = columns
        self.grid = [[0 for _ in range(columns)] for _ in range(rows)]

    def set_value(self, x, y, new_value):
        if 0 <= x < self.rows and 0 <= y < self.columns:
            self.grid[x][y] = new_value
        else:
            print("Position out of grid bounds.")

    def change_shape(self, new_rows, new_columns):
        if new_rows <= 0 or new_columns <= 0:
            print("Invalid shape. Rows and columns must be positive integers.")
            return

        new_grid = [[0 for _ in range(new_columns)] for _ in range(new_rows)]

        for i in range(min(self.rows, new_rows)):
            for j in range(min(self.columns, new_columns)):
                new_grid[i][j] = self.grid[i][j]

        self.rows = new_rows
        self.columns = new_columns
        self.grid = new_grid

    def display(self):
        for i in range(self.rows):
            for j in range(self.columns):
                print(self.grid[i][j], end=' ')
            print()



class DataPack:
    def __init__(self):
        self.containers = []

    def add_container(self, *containervalues):
        self.containers.append(list(containervalues))

    def remove_container(self, containernumber):
        if containernumber < len(self.containers):
            del self.containers[containernumber]
        else:
            print("Container number does not exist.")

    def delete_container_value(self, containernumber, valuenumber):
        if containernumber < len(self.containers):
            container = self.containers[containernumber]
            if valuenumber < len(container):
                del container[valuenumber]
            else:
                print("Value number does not exist in the container.")
        else:
            print("Container number does not exist.")

    
